---
title: Credits
---

Development Lead
================

-   Matias Agustin Mendez \<<matagus@gmail.com>\>

Contributors
============

-   Matt Fisher (<https://github.com/MattFisher>)
-   annikaC (<https://github.com/annikaC>)
-   Andy Kilner (<https://github.com/gnublade>)
